==> haskell-vector-sized-1.5.0-101-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-sized
version:              1.5.0
visibility:           public
id:                   vector-sized-1.5.0-4BxFsXMet3W5lqVEgonT0k
key:                  vector-sized-1.5.0-4BxFsXMet3W5lqVEgonT0k
license:              BSD-3-Clause
copyright:            2016 Joe Hermaszewski
maintainer:           whats.our.vector.victor@monoid.al
author:               Joe Hermaszewski
homepage:             https://github.com/expipiplus1/vector-sized#readme
synopsis:             Size tagged vectors
description:          Please see README.md
category:             Data
abi:                  e845956e3555e6fb93bac4e0656a5484
exposed:              True
exposed-modules:
    Data.Vector.Generic.Mutable.Sized
    Data.Vector.Generic.Mutable.Sized.Internal
    Data.Vector.Generic.Sized Data.Vector.Generic.Sized.Internal
    Data.Vector.Mutable.Sized Data.Vector.Primitive.Mutable.Sized
    Data.Vector.Primitive.Sized Data.Vector.Sized
    Data.Vector.Storable.Mutable.Sized Data.Vector.Storable.Sized
    Data.Vector.Unboxed.Mutable.Sized Data.Vector.Unboxed.Sized

hidden-modules:       Paths_vector_sized
import-dirs:          /usr/lib/ghc-9.0.2/site-local/vector-sized-1.5.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/vector-sized-1.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-sized
hs-libraries:         HSvector-sized-1.5.0-4BxFsXMet3W5lqVEgonT0k
depends:
    adjunctions-4.4.2-FP2PwlGlhSkKIPEjgFd7fk base-4.15.1.0
    binary-0.8.8.0 comonad-5.0.8-Jb01JIbkjpK9yzpetzUNIv deepseq-1.4.5.0
    distributive-0.6.2.1-9wcbdvxUhl373VFDpLmb6H
    finite-typelits-0.1.6.0-AHJceRwxtWj3RcupAUtr2q
    hashable-1.4.1.0-LUNCtsUMK7L3ZB2KEKWF7F
    indexed-list-literals-0.2.1.3-ACMb2XIV2kKDNUSYTyNfwy
    primitive-0.7.4.0-CfTIpXUHtu665Ilg6bT1BW
    vector-0.13.0.0-80dNWv5W93FGfZf7Ao5mAf

haddock-interfaces:
    /usr/share/doc/haskell-vector-sized/html/vector-sized.haddock

haddock-html:         /usr/share/doc/haskell-vector-sized/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-sized-1.5.0-105-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-sized
version:              1.5.0
visibility:           public
id:                   vector-sized-1.5.0-8zk5j98wsPIza5F0NrSTW
key:                  vector-sized-1.5.0-8zk5j98wsPIza5F0NrSTW
license:              BSD-3-Clause
copyright:            2016 Joe Hermaszewski
maintainer:           whats.our.vector.victor@monoid.al
author:               Joe Hermaszewski
homepage:             https://github.com/expipiplus1/vector-sized#readme
synopsis:             Size tagged vectors
description:          Please see README.md
category:             Data
abi:                  31628f8ce68c6df05e45b01ffb10257a
exposed:              True
exposed-modules:
    Data.Vector.Generic.Mutable.Sized
    Data.Vector.Generic.Mutable.Sized.Internal
    Data.Vector.Generic.Sized Data.Vector.Generic.Sized.Internal
    Data.Vector.Mutable.Sized Data.Vector.Primitive.Mutable.Sized
    Data.Vector.Primitive.Sized Data.Vector.Sized
    Data.Vector.Storable.Mutable.Sized Data.Vector.Storable.Sized
    Data.Vector.Unboxed.Mutable.Sized Data.Vector.Unboxed.Sized

hidden-modules:       Paths_vector_sized
import-dirs:          /usr/lib/ghc-9.0.2/site-local/vector-sized-1.5.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/vector-sized-1.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-sized
hs-libraries:         HSvector-sized-1.5.0-8zk5j98wsPIza5F0NrSTW
depends:
    adjunctions-4.4.2-B1WAKMF9vISF0IZ71tfZHo base-4.15.1.0
    binary-0.8.8.0 comonad-5.0.8-HfmAOPlFNu29hdSY8Glwgr deepseq-1.4.5.0
    distributive-0.6.2.1-CHPhCM075vGDbf02dWFJGH
    finite-typelits-0.1.6.0-y8BQ1tHw9y7fE8tvKBlZy
    hashable-1.4.1.0-DXpj0ho9mwSB6ue30MIccy
    indexed-list-literals-0.2.1.3-E7wokD4l7sHFjOKnC9gN02
    primitive-0.7.4.0-9TVgKpsxQ9UKsTlz0zg7yv
    vector-0.13.0.0-C4IY0qsV06C5Tx1gtETdzw

haddock-interfaces:
    /usr/share/doc/haskell-vector-sized/html/vector-sized.haddock

haddock-html:         /usr/share/doc/haskell-vector-sized/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
